"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseTxForKnownErrors = exports.containsJupiterProgram = exports.TransactionErrors = void 0;
const constants_1 = require("./constants");
var TransactionErrors;
(function (TransactionErrors) {
    // Slippage incurred was higher than user expected
    TransactionErrors[TransactionErrors["JupiterSlippageToleranceExceeded"] = 0] = "JupiterSlippageToleranceExceeded";
    TransactionErrors[TransactionErrors["Unknown"] = 1] = "Unknown";
})(TransactionErrors = exports.TransactionErrors || (exports.TransactionErrors = {}));
function containsJupiterProgram(logMessages) {
    return (logMessages.some((msg) => msg.includes(constants_1.JUPITER.V3.toBase58())) ||
        logMessages.some((msg) => msg.includes(constants_1.JUPITER.V4.toBase58())) ||
        logMessages.some((msg) => msg.includes(constants_1.JUPITER.V6.toBase58())));
}
exports.containsJupiterProgram = containsJupiterProgram;
async function parseTxForKnownErrors(connection, signature) {
    const tx = await connection.getTransaction(signature, {
        commitment: 'confirmed',
        maxSupportedTransactionVersion: 0,
    });
    if (tx && tx.meta && tx.meta.logMessages) {
        if (tx.meta.logMessages.some((msg) => msg.includes('SlippageToleranceExceeded')) &&
            containsJupiterProgram(tx.meta.logMessages)) {
            return TransactionErrors.JupiterSlippageToleranceExceeded;
        }
    }
    return TransactionErrors.Unknown;
}
exports.parseTxForKnownErrors = parseTxForKnownErrors;
